// check URL parameters and fill up the form

check_url();
// Check if URL has parameters
function check_url() {
  var url_string = window.location.href;
  var url = new URL(url_string);

  if (url.searchParams.get("utm_source") !== null) {
    store_parameter();
    fill_form();
  } else {
    check_storage();
  }
}

function store_parameter() {
  var url_string = window.location.href;
  var url = new URL(url_string);

  // store parameters in a variable
  var source = url.searchParams.get("utm_source");
  var medium = url.searchParams.get("utm_medium");
  var campaign = url.searchParams.get("utm_campaign");
  var content = url.searchParams.get("utm_content");

  sessionStorage.setItem("utm_source", source);
  sessionStorage.setItem("utm_medium", medium);
  sessionStorage.setItem("utm_campaign", campaign);
  sessionStorage.setItem("utm_content", content);
}

function check_storage() {
  if (sessionStorage.getItem("utm_source") !== null) {
    fill_form();
  } else {
    document.getElementById("source").value = "Direct Traffic";
  }
}

function fill_form() {
  document.getElementById("source").value =
    sessionStorage.getItem("utm_source");
  document.getElementById("medium").value =
    sessionStorage.getItem("utm_medium");
  document.getElementById("campaign").value =
    sessionStorage.getItem("utm_campaign");
  document.getElementById("content").value =
    sessionStorage.getItem("utm_content");
}

//send form data to make.com

//grab form element
const form = document.querySelector("#wf-form-companies-form");
const formBtn = document.querySelector("#submit");
const success = document.querySelector("#success");
const error = document.querySelector("#error");

//grab form values
const fName = document.querySelector("#first-name");
const lName = document.querySelector("#last-name");
const email = document.querySelector("#email");
const cc = document.querySelector("#country-code");
const phNumber = document.querySelector("#phone-number");
const profession = document.querySelector("#profession");
const workplace = document.querySelector("#workplace");
const source = document.querySelector("#source");
const medium = document.querySelector("#medium");
const campaign = document.querySelector("#campaign");
const formCountry = document.querySelector("#country");
const content = document.querySelector("#content");
const formDetails = document.querySelector("#details");
let formError = false;
let formData = new FormData();

//hide all the helper text and error
removeErrors();

//prevent default

form.addEventListener("submit", (e) => {
  e.preventDefault();
  formError = false;
  removeErrors();
  checkForEmpty();

  if (formError == false) {
    //append data to the form

    formData.append("fName", fName.value);
    formData.append("lName", lName.value);
    formData.append("email", email.value);
    formData.append("phNumber", cc.value + phNumber.value);
    formData.append("workplace", workplace.value);
    formData.append("source", source.value);
    formData.append("medium", medium.value);
    formData.append("campaign", campaign.value);
    formData.append("formCountry", formCountry.value);
    formData.append("content", content.value);
    formData.append("details", formDetails.value);

    //send the data to webhook
    formBtn.value = "Processing..";

    fetch("https://hook.us1.make.com/bd445g5rqgaxrc5f4jta7vfxw6mlfyis", {
      method: "POST",
      "Content-Type": "multipart/form-data; boundary=---generatedboundary",
      body: formData,
    })
      .then((response) => {
        if (response.ok) {
          return response.json();
        } else {
          return response.text().then((text) => {
            throw new Error(text);
          });
        }
      })
      .then((data) => {
        formBtn.value = "Submit";
        form.style.display = "none";
        error.style.display = "none";
        success.style.display = "block";
        success.scrollIntoView();
      })
      .catch((err) => {
        formBtn.value = "Submit";
        error.style.display = "block";
        form.style.display = "grid";
        success.style.display = "none";
      });
  }
});

function checkForEmpty() {
  if (fName.value === "") {
    setErrorFor(fName, "First name cannot be blank");
  }

  if (lName.value === "") {
    setErrorFor(lName, "Last name cannot be blank");
  }

  if (email.value === "") {
    setErrorFor(email, "Email name cannot be blank");
  } else {
    if (!isEmail(email.value)) {
      setErrorFor(email, "Not a valid email");
    }
  }

  if (document.querySelector("#phone-number").value === "") {
    setErrorFor(
      document.querySelector("#phone-number"),
      "Phone number cannot be empty"
    );
  } else {
    if (!isPhone(document.querySelector("#phone-number").value)) {
      setErrorFor(
        document.querySelector("#phone-number"),
        "Enter a valid phone number"
      );
    }
  }
}

function setErrorFor(input, message) {
  input.classList.add("is--error");
  const formControl = input.parentElement;
  const helper = formControl.querySelector(".helper");
  helper.classList.remove("hide");
  const errText = helper.querySelector(".helper-text");
  errText.innerText = message;
  errText.classList.add("is--red-4");
  formError = true;
}

function isEmail(email) {
  return /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/.test(
    email
  );
}

function isPhone(phone) {
  return /^[0-9-+s()]*$/.test(phone);
}

function removeErrors() {
  const helper = form.querySelectorAll(".helper");
  helper.forEach((help) => {
    help.classList.add("hide");
    const helperText = help.querySelector(".helper-text");
    helperText.classList.remove("is--red-4");
  });

  const formInput = form.querySelectorAll("input");
  formInput.forEach((input) => {
    input.classList.remove("is--error");
  });

  const formSelect = form.querySelectorAll("select");
  formSelect.forEach((selection) => {
    selection.classList.remove("is--error");
  });
}
